#
# spec file for package libKF5NetworkManagerQt
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soversion 6
%define _tar_path 5.103
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
# Only needed for the package signature condition
%bcond_without released
Name:           libKF5NetworkManagerQt
Version:        5.111.0
Release:        1.1
Summary:        A Qt wrapper for NetworkManager DBus API
License:        LGPL-2.1-only OR LGPL-3.0-only
URL:            https://www.kde.org
Source:         networkmanager-qt-%{version}.tar.xz
%if %{with released}
Source1:        networkmanager-qt-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5Core) >= 5.15.0
BuildRequires:  cmake(Qt5DBus) >= 5.15.0
BuildRequires:  cmake(Qt5Network) >= 5.15.0
BuildRequires:  pkgconfig(libnm) >= 1.0.0

%description
NetworkManagerQt provides access to all NetworkManager features
exposed on DBus. It allows you to manage your connections and control
your network devices and also provides a library for parsing connection
settings which are used in DBus communication.

%package devel
Summary:        A Qt wrapper for NetworkManager DBus API
Requires:       libKF5NetworkManagerQt%{soversion} = %{version}
Requires:       cmake(Qt5Core) >= 5.15.0
Requires:       cmake(Qt5DBus) >= 5.15.0
Requires:       cmake(Qt5Network) >= 5.15.0
Requires:       pkgconfig(libnm) >= 1.0.0

%description devel
NetworkManagerQt provides access to all NetworkManager features
exposed on DBus. It allows you to manage your connections and control
your network devices and also provides a library for parsing connection
settings which are used in DBus communication. Development files.

%package -n libKF5NetworkManagerQt%{soversion}
Summary:        A Qt wrapper for NetworkManager DBus API

%description -n libKF5NetworkManagerQt%{soversion}
NetworkManagerQt provides access to all NetworkManager features
exposed on DBus. It allows you to manage your connections and control
your network devices and also provides a library for parsing connection
settings which are used in DBus communication.

%prep
%autosetup -p1 -n networkmanager-qt-%{version}

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%ldconfig_scriptlets -n libKF5NetworkManagerQt%{soversion}

%files -n libKF5NetworkManagerQt%{soversion}
%license LICENSES/*
%{_kf5_debugdir}/networkmanagerqt.categories
%{_kf5_debugdir}/*.renamecategories
%{_kf5_libdir}/libKF5NetworkManagerQt.so.*

%files devel
%{_kf5_includedir}/
%{_kf5_libdir}/cmake/KF5NetworkManagerQt/
%{_kf5_libdir}/libKF5NetworkManagerQt.so

%changelog
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- Changes since 5.109.0:
  * Build examples on KDE CI
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
  * Include only needed headers instead of QtDBus module header
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * Add Q_ENUM to VPN Connection enums
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- No code change since 5.104.0
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * settings: fix -Wlto-type-mismatch in NetworkManager::checkVersion decl
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- Changes since 5.102.0:
  * Fix remaining 5 compile warnings (unused parameters)
  * Fix builds with examples: they were not compiling
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Explicitly look for Qt::DBus in the CMake config file
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- No code change since 5.100.0
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * DeviceStatistics: Replace setRefreshRateMs call with manual DBus call
  * Remove dead CMakeLists code
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * Export NetworkManager namespace
  * Guard access to wirelessNetworkInterface in wirelessNetwork (kde#459500)
  * .gitlab-ci.yml: enable static builds
  * Rename interfacesAdded slot in manager to dbusInterfacesAdded
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- No code change since 5.97.0
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- No code change since 5.96.0
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * Don't duplicate headers between cpp/.h files
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- No code change since 5.94.0
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * WirelessNetwork: Fix reference access point for the active network
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Require unittests to pass for CI jobs to pass
  * Connect in the correct order everywhere
  * Remove workaround for properties changing
  * Do not create devices to just find out the type
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- No code change since 5.91.0
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Fix emitting signals containing QDBusObjectPath arguments with Qt6
  * Don't write to QByteArray out of bounds
  * Make de/serializing of the parity option symmetric
  * Add CI qt6 support
  * Add support for WPA3-Enterprise 192-bit mode
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Use QStringView in qt6 only
  * Make it compile against qt6
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- No code change since 5.88.0
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * cmake: use imported targets
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- No code change since 5.85.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Remove faulty semicolon
  * Fix build: missing semicolon
  * feat: add assigned-mac-address
  * Expose mDNS configuration used by NM plugins
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- No code change since 5.83.0
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Fix missing definition for IPv6 property when building against older NM
  * Bump required CMake version to 3.16
  * IPv6Setting: add option to disable IPv6
  * fix(pppoe): add parent
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- No code change since 5.81.0
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * Remove dead cmake code
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- No code change since 5.79.0
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * Add missing include
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- No code change since 5.77.0
* Mon Dec  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- No code change since 5.76.0
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Add enum and declarations to allow passing capabilities
    in the registration process to NetworkManager
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- No code change since 5.74.0
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Remove obsolete COPYING files
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Remove secrets logging
  * Use KF-standardized Qt logging categories
  * Use camelcase include. (scripted)
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- No code change since 5.71.0
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- No code change since 5.70.0
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * Replace foreach with range-for
  * [NetworkManager-qt] Replace foreach with range for, hopefully last pass
  * [NetworkManager-qt] Replace foreach with range/index for loop, third pass
  * [NetworkManager-qt] Replace foreach with range/index for loop
  * [NetworkManager-qt] replace foreach (deprecated) with range-for, first pass
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * Fix minor EBN issues
  * NetworkManager-Qt: Convert license headers to SPDX expressions
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::.
  * Support SAE in securityTypeFromConnectionSetting
  * Drop qmake pri file generation & installation, currently broken
  * Use ecm_qt_install_logging_categories over manual categories file
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * [networkmanager-qt] Port QRegExp to QRegularExpression
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Manager: add support for AddAndActivateConnection2
  * cmake: Consider NM headers as system includes
  * Sync Utils::securityIsValid with NetworkManager (kde#415670)
  * Update the obsolete projects.kde.org URL
- Drop 0001-Sync-Utils-securityIsValid-with-NetworkManager.patch
  (merged upstream)
* Sat Jan  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix compatibility with NM 1.22 (kde#415670):
  * 0001-Sync-Utils-securityIsValid-with-NetworkManager.patch
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- No code change since 5.64.0
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Add support for SAE authentication used by WPA3
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Port away from deprecated methods in Qt 5.14
  * ActiveConnection: connect stateChanged() signal to correct interface
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Rename WirelessDevice::lastRequestScanTime to WirelessDevice::lastRequestScan
  * Add property lastScanTime and lastRequestTime to WirelessDevice
  * Remove unused includes
  * ActiveConnection: connect stateChanged() signal to correct interface
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * device: include reapplyConnection() in the interface
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
- Drop patches for Leap 42.3 which is no longer supported:
  * 0001-Revert-Require-NetworkManager-1.4.0-and-newer.patch
  * 0001-Revert-Add-missing-ipv4-setting-options.patch
  * 0001-Revert-Add-IpTunnel-setting.patch
  * 0001-Revert-Add-vxlan-setting.patch
  * 0001-Revert-Add-missing-IPv6-options.patch
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Install in new logging directory when we use kf5 5.59.0
* Sun Jun  9 2019 wbauer@tmo.at
- Refresh patch to fix build on Leap 42.3:
  * 0001-Revert-Require-NetworkManager-1.4.0-and-newer.patch
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Don't fetch device statistics upon construction
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Add WireGuard device support to manager
  * Add WireGuard device
  * WireGuard: Do not require 'private-key' to be non-empty for 'private-key-flags'
  * WireGuard: workaround wrong secret flag type
  * WireGuard: private-key and preshared-keys can be requested together
* Mon Apr 15 2019 wbauer@tmo.at
- Refresh patches to fix build on Leap 42.3:
  * 0001-Revert-Add-IpTunnel-setting.patch
  * 0001-Revert-Add-vxlan-setting.patch
  * 0001-Revert-Require-NetworkManager-1.4.0-and-newer.patch
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * WireGuard: make marshalling/demarshalling of secrets from map to work
  * Fix constructors
  * Add missing support for WireGuard into base setting class
  * WireGuard: fix constructor
  * WireGuard: fix name
  * Wireguard: handle private key as secrets
  * Fix tcsetting test
  * Wireguard: peers property should be NMVariantMapList
  * Add Wireguard connection type support
  * ActiveConnecton: add stateChangedReason signal where we can see the reason of state change
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * No code changes since 5.55.0
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * No code changes since 5.54.0
* Mon Jan 14 2019 wbauer@tmo.at
- Refresh patches to fix build on Leap 42.3:
  * 0001-Revert-Add-IpTunnel-setting.patch
  * 0001-Revert-Add-missing-IPv6-options.patch
  * 0001-Revert-Add-missing-ipv4-setting-options.patch
  * 0001-Revert-Add-vxlan-setting.patch
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * [proxysetting] Fix build with NM 1.4
  * Added DCB settings
  * A minor typo in ipv4 test
  * A minor bug in ipv4 and ipv6 test
  * macsec setting
  * TeamPortSetting: fix argument
  * team-port setting
  * match and tc setting
  * Add missing defines
  * ovs-patch and ovs-port setting
- Dropped patches, now upstream:
  * Add-missing-defines.patch
  * fix-build-with-NM-1.4.patch
* Wed Dec 12 2018 wbauer@tmo.at
- Refresh patches:
  * 0001-Revert-Require-NetworkManager-1.4.0-and-newer.patch
  * 0001-Revert-Add-missing-ipv4-setting-options.patch
  * 0001-Revert-Add-vxlan-setting.patch
- Add some more patches to fix build with older NetworkManager
  versions (as in Leap 42.3 in particular):
  * 0001-Revert-Add-IpTunnel-setting.patch
  * 0001-Revert-Add-missing-IPv6-options.patch
  * Add-missing-defines.patch
  * fix-build-with-NM-1.4.patch
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Get rid of some unneeded defines
  * Fixed a bug(error?) in ipv4 & ipv6 settings
  * Add missing defines
  * Add ovs-bridge and ovs-interface setting
  * Update Ip-tunnel settings
  * Add proxy and user setting
  * Add IpTunnel setting
  * We can now build tun setting test all the time
  * Add missing IPv6 options
  * Listen for added DBus interfaces instead of registered services (kde#400359)
  * Remove qt include prefix
  * normalize signal/slot
* Mon Nov 12 2018 wbauer@tmo.at
- Add patches that remove some new settings on Leap 42.3 (that
  would require a newer NetworkManager) to fix the build:
  * 0001-Revert-Add-missing-ipv4-setting-options.patch
  * 0001-Revert-Add-vxlan-setting.patch
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Remove unused variable
  * Add missing ipv4 setting options
  * Add vxlan setting
  * Create own categories file
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * More nullptr usage
  * Use matching enum value AuthEapMethodUnknown to compare a AuthEapMethod
  * Fix minor EBN issues
* Fri Sep 14 2018 Wolfgang Bauer <wbauer@tmo.at>
- Add 0001-Revert-Require-NetworkManager-1.4.0-and-newer.patch to
  make it build on Leap 42.3 which only has NetworkManager 1.0.
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Remove notes from API documentation about older NM versions
  * Require NetworkManager 1.4.0 and newer
  * manager: add support to R/W the GlobalDnsConfiguration property
  * Actually allow to set the refresh rate for device statistics
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * None
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Remove QT definitions duplicated from KDEFrameworkCompilerSettings or dead
* Wed Jun 27 2018 bjorn.lie@gmail.com
- Align with what cmake looks for:
  * Drop pkgconfig(NetworkManager), pkgconfig(libnm-glib) and
    pkgconfig(libnm-util) BuildRequires and Requires.
  * Add pkgconfig(libnm) BuildRequires and Requires.
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Add missing override
  * Use override
  * Make information about unhandled property just debug messages
  * WirelessSetting: implement assignedMacAddress property
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * None
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Export the NetworkManager include dirs.
  * Start requiring NM 1.0.0
  * We depend against 5.8.0
  * We use qt5.8.0
  * device: define StateChangeReason and MeteredStatus as Q_ENUMs
  * Fix conversion of AccessPoint flags to capabilities
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * None
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove not necessary virtual keyword
  * 802-11-x: support for PWD EAP method
  * it was split
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Remove redundant map look-ups
  * Don't do unnecessary QString allocations to convert parts of it into strings
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Fix 8021xSetting unit test
  * 8021xSetting: domain-suffix-match is defined in NM 1.2.0 and newer
  * Support "domain-suffix-match" in Security8021xSetting
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * None
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * None
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Adding support to ipv*.route-metric
  * Fix undefined NM_SETTING_WIRELESS_POWERSAVE_FOO enums (kde#382051)
  * Add .arcconfig
- Drop Fix-undefined-enums.patch (merged upstream)
* Wed Jul 12 2017 wbauer@tmo.at
- Add Fix-undefined-enums.patch to make it build with NM 1.0.x on
  Leap 42 (kde#382051)
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Too many changes to list here
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * None
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Fix crash when retrieving active connection list. (kde#373993)
  * -Wheader-guard
  * -Wheader-guard
  * Fix unit test
  * Set default value for auto-negotiation based on running NM version
  * One more attempt to fix unit test for active connections
  * Fix unit test for active connections
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * WiredSetting: return autonegotiate even when it's disabled
  * Prevent signals in glib2 be defined by Qt
  * prevent signals in glib2 be defined by Qt
  * WiredSetting: Speed and duplex can be set only when auto-negotiation is off
  * Auto-negotiate value for wired setting should be false
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Sync introspections and generated files with NM 1.6.0
  * Manager: Fix emitting deviceAdded twice when NM restarts
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Wed Nov 16 2016 hrvoje.senjan@gmail.com
- Raise (Build)Required NM version to 0.9.10.0 (as per CMakeLists.txt)
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Fix include dir in pri file
  * Fix moc error due to Q_ENUMS being used in a namespace,
    with Qt branch 5.8
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * We need to set the state during initialization
  * Replace all blocking calls for initialization with
    just one blocking call
  * Use standard o.f.DBus.Properties interface for PropertiesChanged
    signal for NM 1.4.0+ (kde#367938)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
- Drop upstreamed fix-icons-with-NM-1.4.0.patch
* Sun Sep 25 2016 wbauer@tmo.at
- Add fix-icons-with-NM-1.4.0.patch to work around a bug in
  NetworkManager 1.4.0 that causes wrong status icons (kde#367938)
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Default to WPA2-PSK and WPA2-EAP when getting security
    type from connection settings
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Sun Jul 10 2016 hrvoje.senjan@gmail.com
- Raise NM BuildRequires to 0.9.10.0 so it matches reality
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Do not set peap label based on peap version
  * Make network manager version checks in runtime
    (to avoid compile vs. run-time (kde#362736))
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Revert "drop WiMAX support for NM 1.2.0+" as it breaks ABI
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * ConnectionSettings: Initialize gateway ping timeout
  * New TunSetting and Tun connection type
  * Create devices for all known types
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Re-check connection state and other properties to be sure
    they are actual (version 2) (kde#352326)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Make it work with older NM versions
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
- Drop upstreamed 0001-make-it-work-with-older-NM-versions.patch
* Wed Dec 16 2015 alarrosa@suse.com
- Added 0001-make-it-work-with-older-NM-versions.patch committed also
  upstream. This adds some #ifdefs around code that needs NM 0.9.10
  so it also builds with NM 0.9.8
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Fix introspections, LastSeen should be in AccessPoint and
    not in ActiveConnection
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Added new properties from the latest NM snapshot/releases
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Drop WiMAX support for NM 1.2.0+
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * The installed headers are now organized like all other frameworks
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
- NetworkManager is a public dep, so add the correct requires to
  devel package (pkgconfig(NetworkManager), pkgconfig(libnm-glib)
  and pkgconfig(libnm-util))
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Add new properties and methods from NetworkManager 1.0.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Do not print a message about unhandled "AccessPoints" property
  * Added support for NetworkManager 1.0.0 (not required)
  * Fixed VpnSetting secrets handling
  * Added class GenericSetting for connections not managed by
    NetworkManager
  * Added property AutoconnectPriority to ConnectionSettings
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
- Drop vpn.patch, merged upstream
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Added vpn.patch from upstream
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Libary is now officially a part of KDE Frameworks 5 libraries
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
- Update summary and descriptions
- Be more explicit about BuildRequires (using pkgconfig, etc)
- Added baselibs.conf
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * Do not notify about changed VpnState twice
  * Watch for changes when constructing new ModemDevice
  * Add workaround to properly update IpInterface
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Fri Sep 26 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Mnor bugfixes since previous release
* Sun Aug 10 2014 hrvoje.senjan@gmail.com
- Update to 5.0.92
  * Bugfix release
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Version update to 5.0.91
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Activate libKF5NetworkManagerQt package
